"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
/*
    The name used to identify the tour in the tours mapping.
    The string declared here is written to the user.json file to register
    that the tour has already been taken.

    Note: changing the strings will cause the user to receive the tour again!
*/
var TourName;
(function (TourName) {
    TourName["INTRO"] = "Intro";
    TourName["PIVOT"] = "Pivot";
    TourName["TUTORIAL"] = "Tutorial";
    TourName["COLUMN_FORMULAS"] = "Column_Formulas";
    TourName["EXPLORE_DATA"] = "Explore_Datasets";
})(TourName = exports.TourName || (exports.TourName = {}));
// Location to display the TourStep popup
var TourPopupLocation;
(function (TourPopupLocation) {
    TourPopupLocation["BOTTOM_LEFT"] = "bottom_left";
    TourPopupLocation["BOTTOM_RIGHT"] = "bottom_right";
    TourPopupLocation["TOP_LEFT"] = "top_left";
    TourPopupLocation["TOP_RIGHT"] = "top_right";
})(TourPopupLocation = exports.TourPopupLocation || (exports.TourPopupLocation = {}));
const introTourSteps = [
    {
        tourName: TourName.INTRO,
        stepNumber: 1,
        stepHeader: 'The Mito Spreadsheet',
        stepHeaderBackgroundColor: '#BCDFBC',
        stepText: react_1.default.createElement("div", null, " The Mito Spreadsheet is home base. It's where you can see your data and write spreadsheet formulas, keeping you connected to your data. "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: false,
    },
    {
        tourName: TourName.INTRO,
        stepNumber: 2,
        stepHeader: 'The Mito Toolbar',
        stepHeaderBackgroundColor: '#DDA1A1',
        stepText: react_1.default.createElement("div", null, " The Mito Toolbar is where you can find Mito\u2019s powerful point and click analysis tools, including pivot tables, merging datasets together, and full screen mode. "),
        location: TourPopupLocation.TOP_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.INTRO,
        stepNumber: 3,
        stepHeader: 'The Generated Code',
        stepHeaderBackgroundColor: '#79C2F8',
        stepText: react_1.default.createElement("div", null, "Each time you edit your data, Mito generates the equivalent pandas code in the code cell right below the Mito Sheet. You can run the generated code to keep using the edited dataframes in your notebook as you normally would."),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
];
const pivotTourSteps = [
    {
        tourName: TourName.PIVOT,
        stepNumber: 1,
        stepHeader: 'Creating a Pivot Table',
        stepHeaderBackgroundColor: '#BCDFBC',
        stepText: react_1.default.createElement("div", null,
            "  ",
            react_1.default.createElement("b", null, " Click on the Pivot button"),
            " to get started. Mito\u2019s pivot tables make it easy to slice and dice your data into different categories. "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true,
    },
    {
        tourName: TourName.PIVOT,
        stepNumber: 2,
        stepHeader: 'Configure your Pivot Table',
        stepHeaderBackgroundColor: '#DDA1A1',
        stepText: react_1.default.createElement("div", null,
            " In the open sidebar, ",
            react_1.default.createElement("b", null, "select a row and value "),
            " to create your pivot table."),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.PIVOT,
        stepNumber: 3,
        stepHeader: 'That was Easy!',
        stepHeaderBackgroundColor: '#79C2F8',
        stepText: react_1.default.createElement("div", null,
            "Each time you create a pivot table, a new dataframe is created in the Mito Sheet and the generated code. ",
            react_1.default.createElement("b", null, "Checkout the pivot table code below"),
            ". We just saved our first trip to stack overflow :) "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
];
const ColumnFormulasTourSteps = [
    {
        tourName: TourName.COLUMN_FORMULAS,
        stepNumber: 1,
        stepHeader: 'Writing Excel Formulas',
        stepHeaderBackgroundColor: '#BCDFBC',
        stepText: react_1.default.createElement("div", null,
            "  Mito supports the most popular Excel functions, making it easy to transform your data with the formulas you\u2019re most comfortable with. ",
            react_1.default.createElement("b", null, "Click on the Add Col button"),
            " to create a new column.  "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true,
    },
    {
        tourName: TourName.COLUMN_FORMULAS,
        stepNumber: 2,
        stepHeader: 'Open the Cell Editor',
        stepHeaderBackgroundColor: '#DDA1A1',
        stepText: react_1.default.createElement("div", null,
            " ",
            react_1.default.createElement("b", null, "Click on any cell in your new column"),
            " -- it's to the right of your selected column. ",
            react_1.default.createElement("b", null, "Press Enter"),
            " to open the cell editor. "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.COLUMN_FORMULAS,
        stepNumber: 3,
        stepHeader: 'Write your First Formula',
        stepHeaderBackgroundColor: '#79C2F8',
        // eslint-disable-next-line react/display-name
        stepTextFunction: (columnHeader) => {
            const text = `In the cell editor, write the formula =LEN(${columnHeader}) and press Enter. The LEN formula returns the length of each cell in column ${columnHeader}.`;
            return (react_1.default.createElement("div", null, text));
        },
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.COLUMN_FORMULAS,
        stepNumber: 4,
        stepHeader: 'Give your Column a Name',
        stepHeaderBackgroundColor: '#79C2F8',
        // eslint-disable-next-line react/display-name
        stepTextFunction: (columnHeader) => {
            const text = `To give your column a more meaningful name, click on its column header. At the top of the sidebar that appears, name the column Len_of_${columnHeader}`;
            return (react_1.default.createElement("div", null, text));
        },
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.COLUMN_FORMULAS,
        stepNumber: 5,
        stepHeader: "See all of Mito's Formulas",
        stepHeaderBackgroundColor: '#79C2F8',
        stepText: react_1.default.createElement("div", null,
            "Congrats on writing your first formula! To see a full list of Mito\u2019s functions, ",
            react_1.default.createElement("b", null, "click on the Docs"),
            " button in the top right corner of Mito."),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
];
const ExploreDataTourSteps = [
    {
        tourName: TourName.EXPLORE_DATA,
        stepNumber: 1,
        stepHeader: 'Exploring Data with Mito',
        stepHeaderBackgroundColor: '#BCDFBC',
        stepText: react_1.default.createElement("div", null,
            " Mito makes it easy to build intuition for your data by automatically generating summary information about each column. To get started, ",
            react_1.default.createElement("b", null, "click on the filter button in the column header"),
            " of one of your columns."),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true,
    },
    {
        tourName: TourName.EXPLORE_DATA,
        stepNumber: 2,
        stepHeader: 'View Summary Stats',
        stepHeaderBackgroundColor: '#CAD1FF',
        stepText: react_1.default.createElement("div", null,
            " ",
            react_1.default.createElement("b", null, "Click on the Summary Stats tab "),
            " at the bottom of the sidebar. The chart at the top shows you the distribution of your column, and there\u2019s more specific summary information down below. Check it out!"),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.EXPLORE_DATA,
        stepNumber: 3,
        stepHeader: 'Add a Filter',
        stepHeaderBackgroundColor: '#FFDAAE',
        stepText: react_1.default.createElement("div", null,
            "Now that you have a bit of intuition for your data, ",
            react_1.default.createElement("b", null, "switch over to the Filter/Sort Tab "),
            " to clean up your data. "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.EXPLORE_DATA,
        stepNumber: 4,
        stepHeader: "Create a Filter",
        stepHeaderBackgroundColor: '#79C2F8',
        stepText: react_1.default.createElement("div", null,
            "To add a filter, click on the ",
            react_1.default.createElement("b", null, "Add Filter button "),
            " and then set the filter ",
            react_1.default.createElement("b", null, "condition and value"),
            ". "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
    {
        tourName: TourName.EXPLORE_DATA,
        stepNumber: 5,
        stepHeader: "Enjoy your Cleaned Data",
        stepHeaderBackgroundColor: '#FFCBDE',
        stepText: react_1.default.createElement("div", null, "Nice work! In just a few clicks, we\u2019ve built some intuition for our data and removed the values we're not interested in. "),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Continue \u2192"),
        displayBackButton: true
    },
];
const tutorialTourSteps = [
    {
        tourName: TourName.TUTORIAL,
        stepNumber: 1,
        stepHeader: 'Before you Go!',
        stepHeaderBackgroundColor: '#FFDAAE',
        stepText: react_1.default.createElement("div", null,
            "Clean and analyze your data by writing spreadsheet formulas, visualizing your data, and adding filters. Find a more detailed tutorial ",
            react_1.default.createElement("a", { href: "https://docs.trymito.io/getting-started/tutorial", target: "_blank", rel: "noreferrer", style: { color: '#0081DE' } }, "here"),
            "."),
        location: TourPopupLocation.BOTTOM_LEFT,
        advanceButtonText: react_1.default.createElement(react_1.Fragment, null, "Close"),
        displayBackButton: true
    }
];
exports.tours = {
    'Intro': introTourSteps,
    'Pivot': pivotTourSteps,
    'Tutorial': tutorialTourSteps,
    'Column_Formulas': ColumnFormulasTourSteps,
    'Explore_Datasets': ExploreDataTourSteps
};
//# sourceMappingURL=Tours.js.map